@@ -13,19 +13,26 @@
 #' @examples
 #' cars.df = as.disk.frame(cars)
 #' streamacq = make_glm_streaming_fn(cars.df, verbose = FALSE)
-#' m = biglm::bigglm(dist ~ speed, data = streamacq)
-#' summary(m)
-#' predict(m, get_chunk(cars.df, 1))
-#' predict(m, collect(cars.df, 1))
+#' 
+#' majorv = as.integer(version$major)
+#' minorv = as.integer(strsplit(version$minor, ".", fixed=TRUE)[[1]][1])
+#' if(((majorv == 3) & (minorv >= 6)) | (majorv > 3)) {
+#'   m = biglm::bigglm(dist ~ speed, data = streamacq)
+#'   summary(m)
+#'   predict(m, get_chunk(cars.df, 1))
+#'   predict(m, collect(cars.df, 1))
+#' } else {
+#'   m = speedglm::shglm(dist ~ speed, data = streamacq)
+#' }
 make_glm_streaming_fn <- function(data, verbose = FALSE) {
   i = 0
   
   chunkids = disk.frame::get_chunk_ids(data, strip_extension = FALSE)
   is = sample(length(chunkids), replace = FALSE)
-  verbose_copy = verbose
+  verbose = verbose
   nchunks_copy = length(chunkids)
   
-  function(reset = FALSE, verbose = verbose_copy) {
+  function(reset = FALSE) {
     if(reset) {
       if(verbose) {
         print("disk.frame stream has been reset; next read will be from beginning")
