@@ -2,7 +2,7 @@
 using namespace Rcpp;
 
 // [[Rcpp::export]]
-NumericVector hashstr2i(std::vector< std::string >  x, int ngrps) {
+NumericVector hashstr2i(std::vector< std::string >  x, int ngrps, int prime1=3, int prime2=11, int prime3=15) {
   NumericVector out(x.size());
   
   for(uint32_t i =0; i < x.size(); i++)
@@ -14,9 +14,9 @@ NumericVector hashstr2i(std::vector< std::string >  x, int ngrps) {
       hash += (hash << 10);
       hash ^= (hash >> 6);
     }
-    hash += (hash << 3);
-    hash ^= (hash >> 11);
-    hash += (hash << 15);
+    hash += (hash << prime1);
+    hash ^= (hash >> prime2);
+    hash += (hash << prime3);
     
     out[i] = (hash % ngrps) + 1;
   }
